;;
;; Sample startup file for GNU Emacs under emx
;;

;;
;; Enable 8-bit input.  set-input-mode must be called when running
;; Emacs -- calling it before dumping doesn't work.
;;
(set-input-mode nil nil 1)

;;
;; Specify additional frame parameters.
;;
(setq default-frame-alist
      (append '((altgr-modifier . meta))
              default-frame-alist))     ; AltGr (and AltCar) generate M-

;;
;; Display characters 128 through 254 as-is.  Without this
;; statement, octal notation is used for these characters.
;;
(standard-display-8bit 128 254)

;; Use special symbols (which are not displayed as-is when occurring
;; in a buffer) for truncated screen lines (256), continued lines
;; (257) and for displaying control characters notation (259)
;;
(aset standard-display-table 256 16)
(aset standard-display-table 257 31)
(aset standard-display-table 259 24)

;;
;; Raise frame to the foreground if emacsclient requests a buffer.
;;
(add-hook 'server-request-hook
          '(lambda ()
             (make-frame-visible)
             (focus-frame (selected-frame))))

;;
;; Use Kai Uwe Rommel's port of GNU ls.
;;
(add-hook 'dired-load-hook 'emx-dired-kur-ls-setup)

;;
;; Enable OS/2 on-line help.
;;
(autoload 'os2help "os2help" "OS/2 on-line help" t)
(setq os2help "/emx/book/emxdoc.ndx")
(global-set-key [C-f1] 'os2help)

;;
;; Call pm-edit-menu to let the Cut, Copy and Paste choices of the
;; Edit menu use the OS/2 clipboard.
;;
;; Call pm-file-menu to let the `Open File...' and `Save Buffer As...'
;; choices from the File menu use OS/2's standard file dialog.
;;
;; Call remove-from-window-list to remove emacs.exe (the VIO window)
;; from the Window List.  You might want to uncomment that statement
;; if you use the PM interface and don't run Emacs manually.
;;
;; Call pm-session-bond to establish a bond between emacs.exe (the VIO
;; window) and pmemacs.exe (the PM windows).  If you select emacs.exe,
;; for instance by using the Window List, one of the PM windows will
;; be selected instead of emacs.exe.
;;
;; Set the foreground and background colors of the mode line.
;;
;; Use `bold' face instead of `bold-italic' face for info nodes
;;
(if window-system
    (progn
      (pm-edit-menu)
      (pm-file-menu)
      ;;(remove-from-window-list)
      (pm-session-bond t)
      (set-face-background 'modeline "red")
      (set-face-foreground 'modeline "yellow")
      (make-face 'info-node)
      (copy-face 'bold 'info-node)))

;;
;; Set up files and directories for IBM TCP/IP 2.0
;;
(let ((etc (getenv "ETC"))
      mbox)
  (setq etc (if etc (replace-char-in-string etc ?\\ ?/)
              "c:/tcpip/etc/"))
  (setq etc (expand-file-name etc))
  (if (not (string-match "/$" etc))
      (setq etc (concat etc "/")))
  (setq mbox (concat etc "mail/inbox.ndx"))
  (setq rmail-spool-directory (concat etc "mail/"))
  (setq rmail-primary-inbox-list (list mbox))
  (setq display-time-mail-file mbox))

;; End of site-start.el
